; 2600 programming for newbies
; Lesson 18 - Assymetrical Playfields Continued
;
; What this program does:
;	1. Loads playfield data from a set of data tables.
;	The background the program creates is assymetrical 
;	so there are two sets of PF data for every scan line.
;	The tables are unoptimized. There are empty lines
;	full of zeroes which take valuable rom space.
;
;	2. Uses the sleep macro to skip cpu cycles so that
;	PF data for the right side of the screen is written 
;	at the right time.
;

	processor 6502
	include "vcs.h"
	include "macro.h"

	SEG
	org $F000

Reset

 ldx #0
 lda #0

Clear

 sta 0,x
 inx
 bne Clear

StartOfFrame

 lda #0
 sta VBLANK

 lda #2
 sta VSYNC

 sta WSYNC
 sta WSYNC
 sta WSYNC

 lda #0
 sta VSYNC

 ldx #0

VerticalBlank

 sta WSYNC
 inx
 cpx #37
 bne VerticalBlank

 ldx #0		; Init x to count scanlines

 lda #$44	; Set the PF color to red.
 sta COLUPF

ScanGo

 sta WSYNC	; Start counting cycles
		; Sums could be wrong.
			
		; Loading left side PF data. This only takes
		; 19 cycles, well before the TIA starts drawing
		; this side of the screen.			
	
 lda PFData0A,x		; 4
 sta PF0		; 4 + 3
 lda PFData1A,x		; 7 + 4
 sta PF1		; 11 + 3
 lda PFData2A,x		; 12 + 4
 sta PF2		; 16 + 3 = 19

 sleep 10		; 19 + 10

Continue	

; Start loading right side PF Data.
; The sleep macro is used to make sure the PF registers
; are written when the TIA is not using them.

 lda PFData0B,x		; 29 + 4
 sta PF0		; 33 + 3
 
 sleep 3		; 36 + 3
 
 lda PFData1B,x		; 39 + 4
 sta PF1		; 43 + 3

 sleep 4		; 46 + 4

 lda PFData2B,x		; 50 + 4
 sta PF2		; 54 + 3

 inx			; 57 + 2
 cpx #192		; 69 + 2
 bne ScanGo		; 71 + 3

EndFrame 

 lda #%01000010		; 67 + 3
 sta VBLANK		; 70 + 4
 ldx #0			; 74 + 2

OverScan

 sta WSYNC
 inx
 cpx #30
 bne OverScan
 jmp StartOfFrame

;Assymetric Data 

PFData0A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%11100000
    .byte #%10100000
    .byte #%11100000
    .byte #%11100000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11100000
    .byte #%00100000
    .byte #%00100000
    .byte #%11100000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11100000
    .byte #%00100000
    .byte #%00100000
    .byte #%11100000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11100000
    .byte #%00100000
    .byte #%00100000
    .byte #%11100000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11000000
    .byte #%00000000
    .byte #%11100000
    .byte #%00100000
    .byte #%00100000
    .byte #%11100000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11100000
    .byte #%11100000
    .byte #%10100000
    .byte #%11100000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData1A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111111
    .byte #%00001000
    .byte #%11111111
    .byte #%00001000
    .byte #%11111111
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%11111111
    .byte #%11111111
    .byte #%11011111
    .byte #%11111111
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00001100
    .byte #%00000000
    .byte #%00000000
    .byte #%00001111
    .byte #%11111000
    .byte #%00001000
    .byte #%00001111
    .byte #%11111000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111000
    .byte #%00001111
    .byte #%00001000
    .byte #%11111000
    .byte #%00001111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00001111
    .byte #%11111000
    .byte #%00001000
    .byte #%00001111
    .byte #%11111000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111000
    .byte #%00001111
    .byte #%00001000
    .byte #%11111000
    .byte #%00001111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11100000
    .byte #%10100000
    .byte #%10100000
    .byte #%10100000
    .byte #%10100000
    .byte #%10100000
    .byte #%10100000
    .byte #%11100000
    .byte #%11111111
    .byte #%11011111
    .byte #%11111111
    .byte #%11111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData2A

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000011
    .byte #%00000010
    .byte #%00000011
    .byte #%00000010
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%00000011
    .byte #%00000000
    .byte #%11111111
    .byte #%11111110
    .byte #%11011111
    .byte #%11111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111000
    .byte #%00001111
    .byte #%00001000
    .byte #%11111000
    .byte #%00001111
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00011111
    .byte #%11110000
    .byte #%00010000
    .byte #%00011111
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111000
    .byte #%00001111
    .byte #%00001000
    .byte #%11111000
    .byte #%00001111
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00000000
    .byte #%10000000
    .byte #%00011111
    .byte #%11110000
    .byte #%00010000
    .byte #%00011111
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111111
    .byte #%11011111
    .byte #%11111110
    .byte #%11111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData0B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11110000
    .byte #%10110000
    .byte #%11110000
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11000000
    .byte #%01110000
    .byte #%01000000
    .byte #%11000000
    .byte #%01110000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11110000
    .byte #%10000000
    .byte #%10000000
    .byte #%11110000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11000000
    .byte #%01110000
    .byte #%01000000
    .byte #%11000000
    .byte #%01110000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%00010000
    .byte #%00000000
    .byte #%11110000
    .byte #%10000000
    .byte #%10000000
    .byte #%11110000
    .byte #%10000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11110000
    .byte #%11110000
    .byte #%10110000
    .byte #%11110000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData1B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111111
    .byte #%11111111
    .byte #%11110111
    .byte #%11111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000011
    .byte #%11111110
    .byte #%00000010
    .byte #%00000011
    .byte #%11111110
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111110
    .byte #%00000011
    .byte #%00000010
    .byte #%11111110
    .byte #%00000011
    .byte #%00100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000000
    .byte #%01100000
    .byte #%00000011
    .byte #%11111110
    .byte #%00000010
    .byte #%00000011
    .byte #%11111110
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111110
    .byte #%00000011
    .byte #%00000010
    .byte #%11111110
    .byte #%00000011
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%11111111
    .byte #%11110111
    .byte #%11111111
    .byte #%11111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000


PFData2B

    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00111111
    .byte #%00111101
    .byte #%00111111
    .byte #%00111111
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00111111
    .byte #%00100000
    .byte #%00100000
    .byte #%00111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00011000
    .byte #%00000000
    .byte #%00111111
    .byte #%00100000
    .byte #%00100000
    .byte #%00111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00111111
    .byte #%00100000
    .byte #%00100000
    .byte #%00111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00111111
    .byte #%00100000
    .byte #%00100000
    .byte #%00111111
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00110000
    .byte #%00000000
    .byte #%00111111
    .byte #%00111111
    .byte #%00111101
    .byte #%00111111
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000
    .byte #%00000000

	ORG $FFFA

InterruptVectors

	.word Reset 
	.word Reset 
	.word Reset 

 END


